#!/usr/bin/env bash

VERSION=""

while [[ "$#" -gt 0 ]]; do
  case $1 in
    -v|--version)
      VERSION=$2
      shift 2;;
    *)
      shift;;
  esac
done

# Initialize and update git submodules
git submodule init
git submodule update --remote

if [ -n "$VERSION" ]; then
    echo "Required version: $VERSION"
    echo "Pulling files for version: $VERSION"

    for repo in "backend" "showcase-definition" "introductory-definition"; do
        if [ -d "./$repo" ]; then
            cd "./$repo"

            git fetch --tags &>/dev/null
            git checkout main &>/dev/null # Ensure we are on a valid branch before switching
            git checkout tags/$VERSION &>/dev/null

            cd ../  # Return to the main directory
        fi
    done
else
    echo "No version provided, using the NEWEST files."
fi


# # Check the status of the git submodules
git submodule status

# # Create necessary directories
mkdir -p docs/tech
mkdir -p files-from-repos

# Copy files to the respective directories
cp ./backend/definitions/README.md ./docs/tech/architecture/definitions/README.md
cp ./backend/definitions/CHANGELOG.md ./docs/tech/architecture/definitions/CHANGELOG.md
cp ./backend/openapi.yml ./docs/tech/api/openapi.yml

cp ./showcase-definition/assets/definition.zip ./files-from-repos/showcase-definition.zip
cp ./introductory-definition/assets/definition.zip ./files-from-repos/intro-definition.zip
